package EFS::DBI::Prefix;

use strict;
use warnings;
use English;

use base q{DBIx::Class};

# Override DBIx::Class's table/sequence to insert database prefix if necessary

# Separate these for futureproofing
sub tableprefix    { return shift->get_db_prefix(@_) }
sub sequenceprefix { return shift->get_db_prefix(@_) }

sub table {
    my $class = shift ;

    if ( @_ ) {
        my $table       = shift;
        if ( my $prefix = $class->tableprefix ) {
            if ( $table !~ m/\A $prefix \./msx ) {
                $table = join q{.}, $prefix, $table;
            }
        }
        #return $class->next::method($table, @_);
        return $class->next::method($table);
    }

    return $class->next::method;
}

sub sequence {

    my $class = shift ;

    my $dbvendor = $class->get_db_vendor;

    if ( $dbvendor ne q{oracle} ) {
        return;
    }

    if ( @_ ) {
        my $sequence    = shift;
        if ( my $prefix = $class->sequenceprefix ) {
            if ( $sequence !~ m/\A $prefix \./msx ) {
                $sequence = join q{.}, qq{"$prefix"}, qq{"$sequence"};
            }
        }
        #return $class->next::method($sequence, @_);
        return $class->next::method($sequence);
    }

    return $class->next::method;

}

1;

# Local Variables:
#   mode: cperl
#   cperl-indent-level: 4
#   fill-column: 78
# End:
# vim: expandtab shiftwidth=4:
