package EFS::DBI::ResultSet::Feature;

use strict;
use warnings;
use English;

use base q{EFS::DBI::ResultSet};

use Params::Validate qw( :all );

our @feature_names = qw( allow_insecure_disable_lockdown
                         allow_insecure_prod_incr
                         enable_releaselink_compatibility
                         disable_restricted_access );

sub validate_data {

    my $class = shift;
    my %data = @_;

    if ( exists $data{name} ) {
        if ( not grep { $data{name} eq $_ } @feature_names ) {
            die(
                qq{Invalid feature name '$data{name}'\n},
                qq{Must be one of the following:\n\t},
                join( qq{\n\t}, @feature_names ), qq{\n},
            );
        }
    }

    return 1;

}

sub configured {

    my $self = shift;
    my $name = shift;

    my ($feature) = $self->search({ name => $name });

    if ( $feature && $feature->value ) {
        return $feature->value;
    } else {
        return;
    }

}

sub retrieve_bynames_assert {

    my $self = shift;

    my (%args) = validate( @_, {
        name => { type => SCALAR },
    });

    my ($feature) = $self->search({ name => $args{name} });

    if ( not $feature ) {
        die qq{No such feature '$args{name}'\n};
    }

    return $feature;

}

1;

# Local Variables:
#   mode: cperl
#   cperl-indent-level: 4
#   fill-column: 78
# End:
# vim: expandtab shiftwidth=4:
