package EFS::DBI::ResultSet::Location;

use strict;
use warnings;
use English;

use base q{EFS::DBI::ResultSet};

use Params::Validate qw( :all );

sub validate_data {
    my $class = shift;
    my %data  = @_;
    return 1 unless exists $data{location};
        ## no critic ProhibitEnumeratedClasses
        # we really do want a-z here; [:lower:] would be effected by locale
    $data{location} =~ m/\A [a-z0-9]+ \z/msx || die(
        qq{Invalid location '$data{location}'\n},
        qq{Must consist solely of lower case letters and numbers (a-z0-9)\n}
    );
    return 1;
}

sub retrieve_bynames_assert {

    my $self = shift;

    my (%args) = validate( @_, {
        region => { type => SCALAR, optional => 1 },
        campus => { type => SCALAR, optional => 1 },
        name   => { type => SCALAR },
    });

    my $location;

    if ( $args{region} && $args{campus} ) {

        my $campus_rs = EFS::DBI->get_resultset( q{Campus} );

        my $campus = $campus_rs->retrieve_bynames_assert(
            region => $args{region},
            name   => $args{campus},
        );

        ($location) = $self->search({
            campus => $campus->id,
            name   => $args{name},
        });

        if ( not $location ) {
            die qq{No such location $args{region}/$args{campus}/$args{name}\n};
        }

    } else {

        ($location) = $self->search({ name => $args{name} });

        if ( not $location ) {
            die qq{No such location '$args{name}'\n};
        }

    }

    return $location;

}

1;

# Local Variables:
#   mode: cperl
#   cperl-indent-level: 4
#   fill-column: 78
# End:
# vim: expandtab shiftwidth=4:
