package EFS::DBI::ResultSet::Metaproj;

use strict;
use warnings;
use English;

use base q{EFS::DBI::ResultSet};

use Params::Validate qw( :all );

sub validate_data {
    my $class = shift;
    my %data  = @_;
    if ( not exists $data{metaproj} ) {
        return 1;
    }
        ## no critic ProhibitEnumeratedClasses
        # we really do want a-z here; [:lower:] would be effected by locale
    $data{metaproj} =~ m/\A [-a-zA-Z0-9]+ \z/msx || die(
        qq{Invalid metaproj name '$data{metaproj}'\n},
        qq{Must consist solely of alphanumeric characters, and dashes\n},
        qq{NOTE: Underscores are not allowed\n}
    );
    return;
}

sub retrieve_bynames_assert {

    my $self = shift;

    my (%args) = validate( @_, {
        name     => { type => SCALAR },
        disabled => { type => BOOLEAN, optional => 1 },
    });

    my ($metaproj) = $self->search({ name => $args{name} });

    if ( not $metaproj ) {
        die qq{No such metaproj '$args{name}'\n};
    }

    if ( not $args{disabled} ) {
        $metaproj->assert_not_disabled;
    }

    return $metaproj;

}

sub retrieve_bynames {

    my $self = shift;

    my (%args) = validate( @_, {
        name     => { type => SCALAR },
        disabled => { type => BOOLEAN, optional => 1 },
    });

    my ($metaproj) = $self->search({ name => $args{name} });

    return $metaproj;

}

1;

# Local Variables:
#   mode: cperl
#   cperl-indent-level: 4
#   fill-column: 78
# End:
# vim: expandtab shiftwidth=4:
