-- region

create table "region" (
    "id"		number(11)	not null	enable,
    "name"              varchar(24)     not null	enable,
    "description"       varchar(1024)   not null        enable
);

create unique index "region_pk" on "region"("id");

alter table "region" add constraint "region_pk"
primary key ("id") using index "region_pk";

create unique index "region_idx1" on "region"("name");

alter table "region" add constraint "region_idx1"
unique ("name") using index "region_idx1";

create sequence "region_seq";

grant select on "region" to __rouser__;
grant select, insert, update, delete on "region" to __rwuser__;
grant select, alter on "region_seq" to __rwuser__;

-- region_attrs

create table "region_attrs" (
    "id"	number(11)	not null	enable,
    "region"    number(11)      not null	enable,
    "name"      varchar(256)    not null	enable,
    "value"     varchar(512)    not null	enable
);

create unique index "region_attrs_pk" on "region_attrs"("id");

alter table "region_attrs" add constraint "region_attrs_pk"
primary key ("id") using index "region_attrs_pk";

create unique index "region_attrs_idx1" on "region_attrs"("region","name");

alter table "region_attrs" add constraint "region_attrs_idx1"
unique ("region","name") using index "region_attrs_idx1";

alter table "region_attrs" add constraint "region_attrs_fk1"
foreign key ("region") references "region"("id");

create sequence "region_attrs_seq";

grant select on "region_attrs" to __rouser__;
grant select, insert, update, delete on "region_attrs" to __rwuser__;
grant select, alter on "region_attrs_seq" to __rwuser__;

-- campus

create table "campus" (
    "id"              	number(11)	not null	enable,
    "region"		number(11)	not null	enable,
    "name"		varchar(64)	not null	enable,
    "description"       varchar(1024)   not null        enable
);

create unique index "campus_pk" on "campus"("id");

alter table "campus" add constraint "campus_pk"
primary key ("id") using index "campus_pk";

create unique index "campus_idx1" on "campus"("name");

alter table "campus" add constraint "campus_idx1"
unique ("name") using index "campus_idx1";

alter table "campus" add constraint "campus_fk1"
foreign key ("region") references "region"("id");

create sequence "campus_seq";

grant select on "campus" to __rouser__;
grant select, insert, update, delete on "campus" to __rwuser__;
grant select, alter on "campus_seq" to __rwuser__;

-- campus_attrs

create table "campus_attrs" (
    "id"     number(11)	    not null	enable,
    "campus" number(11)     not null	enable,
    "name"   varchar(256)   not null	enable,
    "value"  varchar(512)   not null	enable
);

create unique index "campus_attrs_pk" on "campus_attrs"("id");

alter table "campus_attrs" add constraint "campus_attrs_pk"
primary key ("id") using index "campus_attrs_pk";

create unique index "campus_attrs_idx1" on "campus_attrs"("campus","name");

alter table "campus_attrs" add constraint "campus_attrs_idx1"
unique ("campus","name") using index "campus_attrs_idx1";

alter table "campus_attrs" add constraint "campus_attrs_fk1"
foreign key ("campus") references "campus"("id");

create sequence "campus_attrs_seq";

grant select on "campus_attrs" to __rouser__;
grant select, insert, delete, update on "campus_attrs" to __rwuser__;
grant select, alter on "campus_attrs_seq" to __rwuser__;

-- location

create table "location" (
    "id"                number(11)	not null	enable,
    "campus"            number(11)      not null	enable,
    "name"              varchar(128)    not null	enable,
    "description"       varchar(1024)   not null        enable
);

create unique index "location_pk" on "location"("id");

alter table "location" add constraint "location_pk"
primary key ("id") using index "location_pk";

create unique index "location_idx1" on "location"("name");

alter table "location" add constraint "location_idx1"
unique ("name") using index "location_idx1";

alter table "location" add constraint "location_fk1"
foreign key ("campus") references "campus"("id");

create sequence "location_seq";

grant select on "location" to __rouser__;
grant select, insert, update, delete on "location" to __rwuser__;
grant select, alter on "location_seq" to __rwuser__;

-- location_attrs

create table "location_attrs" (
    "id"		number(11)	not null	enable,
    "location"          number(11)      not null	enable,
    "name"              varchar(256)    not null	enable,
    "value"             varchar(512)    not null	enable
);

create unique index "location_attrs_pk" on "location_attrs"("id");

alter table "location_attrs" add constraint "location_attrs_pk"
primary key ("id") using index "location_attrs_pk";

create unique index "location_attrs_idx1" on "location_attrs"("location","name");

alter table "location_attrs" add constraint "location_attrs_idx1"
unique ("location","name") using index "location_attrs_idx1";

alter table "location_attrs" add constraint "location_attrs_fk1"
foreign key ("location") references "location"("id");

create sequence "location_attrs_seq";

grant select on "location_attrs" to __rouser__;
grant select, insert, update, delete on "location_attrs" to __rwuser__;
grant select, alter on "location_attrs_seq" to __rwuser__;

-- cell

create table "cell" (
    "id"		number(11)	not null	enable,
    "location"          number(11)      not null	enable,
    "name"              varchar(256)    not null	enable,
    "celltype"          varchar(8)      not null	enable,
    "fstype"            varchar(8)      not null	enable,
    "parentcell"        number(11)	null,
    "hidden"            number(1)       default 0   not null	enable,
    "disabled"          number(1)       default 0   not null	enable
);

create unique index "cell_pk" on "cell"("id");

alter table "cell" add constraint "cell_pk"
primary key ("id") using index "cell_pk";

create unique index "cell_idx1" on "cell"("name");

alter table "cell" add constraint "cell_idx1"
unique ("name") using index "cell_idx1";

alter table "cell" add constraint "cell_fk1"
foreign key ("location") references "location"("id");

alter table "cell" add constraint "cell_fk2"
foreign key ("parentcell") references "cell"("id");

create sequence "cell_seq";

grant select on "cell" to __rouser__;
grant select, insert, update, delete on "cell" to __rwuser__;
grant select, alter on "cell_seq" to __rwuser__;

-- cell_attrs

create table "cell_attrs" (
    "id"		number(11)	not null	enable,
    "cell"              number(11)      not null	enable,
    "name"              varchar(256)    not null	enable,
    "value"             varchar(512)    not null	enable
);

create unique index "cell_attrs_pk" on "cell_attrs"("id");

alter table "cell_attrs" add constraint "cell_attrs_pk"
primary key ("id") using index "cell_attrs_pk";

create unique index "cell_attrs_idx1" on "cell_attrs"("cell","name");

alter table "cell_attrs" add constraint "cell_attrs_idx1"
unique ("cell","name") using index "cell_attrs_idx1";

alter table "cell_attrs" add constraint "cell_attrs_fk1"
foreign key ("cell") references "cell"("id");

create sequence "cell_attrs_seq";

grant select on "cell_attrs" to __rouser__;
grant select, insert, update, delete on "cell_attrs" to __rwuser__;
grant select, alter on "cell_attrs_seq" to __rwuser__;

-- fileserver

create table "fileserver" (
    "id"		number(11)	not null	enable,
    "cell"              number(11)    	not null	enable,
    "name"              varchar(128)    not null	enable
);

create unique index "fileserver_pk" on "fileserver"("id");

alter table "fileserver" add constraint "fileserver_pk"
primary key ("id") using index "fileserver_pk";

create unique index "fileserver_idx1" on "fileserver"("name");

alter table "fileserver" add constraint "fileserver_idx1"
unique ("name") using index "fileserver_idx1";

alter table "fileserver" add constraint "fileserver_fk1"
foreign key ("cell") references "cell"("id");

create sequence "fileserver_seq";

grant select on "fileserver" to __rouser__;
grant select, insert, update, delete on "fileserver" to __rwuser__;
grant select, alter on "fileserver_seq" to __rwuser__;

-- fileserver_attrs

create table "fileserver_attrs" (
    "id"		number(11)	not null	enable,
    "fileserver"        number(11)	not null	enable,
    "name"              varchar(256)    not null	enable,
    "value"             varchar(512)    not null	enable
);

create unique index "fileserver_attrs_pk" on "fileserver_attrs"("id");

alter table "fileserver_attrs" add constraint "fileserver_attrs_pk"
primary key ("id") using index "fileserver_attrs_pk";

create unique index "fileserver_attrs_idx1" on "fileserver_attrs"("fileserver","name");

alter table "fileserver_attrs" add constraint "fileserver_attrs_idx1"
unique ("fileserver","name") using index "fileserver_attrs_idx1";

alter table "fileserver_attrs" add constraint "fileserver_attrs_fk1"
foreign key ("fileserver") references "fileserver"("id");

create sequence "fileserver_attrs_seq";

grant select on "fileserver_attrs" to __rouser__;
grant select, insert, update, delete on "fileserver_attrs" to __rwuser__;
grant select, alter on "fileserver_attrs_seq" to __rwuser__;

-- fileshare

create table "fileshare" (
    "id"		number(11)	not null	enable,
    "fileserver"        number(11)    	not null	enable,
    "name"              varchar(128)    not null	enable,
    "filetype"          varchar(4)      null	        enable
);

create unique index "fileshare_pk" on "fileshare"("id");

alter table "fileshare" add constraint "fileshare_pk"
primary key ("id") using index "fileshare_pk";

create unique index "fileshare_idx1" on "fileshare"("fileserver","name");

alter table "fileshare" add constraint "fileshare_idx1"
unique ("fileserver","name") using index "fileshare_idx1";

alter table "fileshare" add constraint "fileshare_fk1"
foreign key ("fileserver") references "fileserver"("id");

create sequence "fileshare_seq";

grant select on "fileshare" to __rouser__;
grant select, insert, update, delete on "fileshare" to __rwuser__;
grant select, alter on "fileshare_seq" to __rwuser__;

-- fileshare_attrs

create table "fileshare_attrs" (
    "id"		number(11)	not null	enable,
    "fileshare"         number(11)    	not null	enable,
    "name"              varchar(256)    not null	enable,
    "value"             varchar(512)    not null	enable
);

create unique index "fileshare_attrs_pk" on "fileshare_attrs"("id");

alter table "fileshare_attrs" add constraint "fileshare_attrs_pk"
primary key ("id") using index "fileshare_attrs_pk";

create unique index "fileshare_attrs_idx1" on "fileshare_attrs"("fileshare","name");

alter table "fileshare_attrs" add constraint "fileshare_attrs_idx1"
unique ("fileshare","name") using index "fileshare_attrs_idx1";

alter table "fileshare_attrs" add constraint "fileshare_attrs_fk1"
foreign key ("fileshare") references "fileshare"("id");

create sequence "fileshare_attrs_seq";

grant select on "fileshare_attrs" to __rouser__;
grant select, insert, update, delete on "fileshare_attrs" to __rwuser__;
grant select, alter on "fileshare_attrs_seq" to __rwuser__;

-- fileqtree

create table "fileqtree" (
    "id"		number(11)	not null	enable,
    "fileshare"         number(11)    	not null	enable,
    "name"              varchar(128)    not null	enable
);

create unique index "fileqtree_pk" on "fileqtree"("id");

alter table "fileqtree" add constraint "fileqtree_pk"
primary key ("id") using index "fileqtree_pk";

create unique index "fileqtree_idx1" on "fileqtree"("fileshare","name");

alter table "fileqtree" add constraint "fileqtree_idx1"
unique ("fileshare","name") using index "fileqtree_idx1";

alter table "fileqtree" add constraint "fileqtree_fk1"
foreign key ("fileshare") references "fileshare"("id");

create sequence "fileqtree_seq";

grant select on "fileqtree" to __rouser__;
grant select, insert, update, delete on "fileqtree" to __rwuser__;
grant select, alter on "fileqtree_seq" to __rwuser__;

-- fileqtree_attrs

create table "fileqtree_attrs" (
    "id"		number(11)	not null	enable,
    "fileqtree"         number(11)    	not null	enable,
    "name"              varchar(256)    not null	enable,
    "value"             varchar(512)    not null	enable
);

create unique index "fileqtree_attrs_pk" on "fileqtree_attrs"("id");

alter table "fileqtree_attrs" add constraint "fileqtree_attrs_pk"
primary key ("id") using index "fileqtree_attrs_pk";

create unique index "fileqtree_attrs_idx1" on "fileqtree_attrs"("fileqtree","name");

alter table "fileqtree_attrs" add constraint "fileqtree_attrs_idx1"
unique ("fileqtree","name") using index "fileqtree_attrs_idx1";

alter table "fileqtree_attrs" add constraint "fileqtree_attrs_fk1"
foreign key ("fileqtree") references "fileqtree"("id");

create sequence "fileqtree_attrs_seq";

grant select on "fileqtree_attrs" to __rouser__;
grant select, insert, update, delete on "fileqtree_attrs" to __rwuser__;
grant select, alter on "fileqtree_attrs_seq" to __rwuser__;

-- efsserver

create table "efsserver" (
    "id"	number(11)	            not null	enable,
    "name"     	varchar(256) 	            not null	enable,
    "hosttype"	varchar(8) 	            not null	enable,
    "disabled"  number(1)       default 0   not null	enable
);

create unique index "efsserver_pk" on "efsserver"("id");

alter table "efsserver" add constraint "efsserver_pk"
primary key ("id") using index "efsserver_pk";

create unique index "efsserver_idx1" on "efsserver"("name");

alter table "efsserver" add constraint "efsserver_idx1"
unique ("name") using index "efsserver_idx1";

create sequence "efsserver_seq";

grant select on "efsserver" to __rouser__;
grant select, insert, update, delete on "efsserver" to __rwuser__;
grant select, alter on "efsserver_seq" to __rwuser__;

-- efsserver_cell

create table "efsserver_cell" (
    "id"		number(11)	not null	enable,
    "efsserver"         number(11)      not null	enable,
    "cell"     	      	number(11)      not null	enable
);

create unique index "efsserver_cell_pk" on "efsserver_cell"("id");

alter table "efsserver_cell" add constraint "efsserver_cell_pk"
primary key ("id") using index "efsserver_cell_pk";

create unique index "efsserver_cell_idx1"
on "efsserver_cell"("efsserver","cell");

alter table "efsserver_cell" add constraint "efsserver_cell_idx1"
unique ("efsserver","cell") using index "efsserver_cell_idx1";

alter table "efsserver_cell" add constraint "efsserver_cell_fk1"
foreign key ("efsserver") references "efsserver"("id");

alter table "efsserver_cell" add constraint "efsserver_cell_fk2"
foreign key ("cell") references "cell"("id");

create sequence "efsserver_cell_seq";

grant select on "efsserver_cell" to __rouser__;
grant select, insert, update, delete on "efsserver_cell" to __rwuser__;
grant select, alter on "efsserver_cell_seq" to __rwuser__;

-- efsserver_attrs

create table "efsserver_attrs" (
    "id"		number(11)	not null	enable,
    "efsserver"         number(11)      not null	enable,
    "name"              varchar(256)    not null	enable,
    "value"             varchar(512)    not null	enable
);

create unique index "efsserver_attrs_pk" on "efsserver_attrs"("id");

alter table "efsserver_attrs" add constraint "efsserver_attrs_pk"
primary key ("id") using index "efsserver_attrs_pk";

create unique index "efsserver_attrs_idx1" on "efsserver_attrs"("efsserver","name");

alter table "efsserver_attrs" add constraint "efsserver_attrs_idx1"
unique ("efsserver","name") using index "efsserver_attrs_idx1";

alter table "efsserver_attrs" add constraint "efsserver_attrs_fk1"
foreign key ("efsserver") references "efsserver"("id");

create sequence "efsserver_attrs_seq";

grant select on "efsserver_attrs" to __rouser__;
grant select, insert, update, delete on "efsserver_attrs" to __rwuser__;
grant select, alter on "efsserver_attrs_seq" to __rwuser__;

-- metaproj

create table "metaproj" (
    "id"		number(11)	not null	enable,
    "name"        	varchar(32)     not null	enable,
    "username"          varchar(8)      not null	enable,
    "groupname"         varchar(8)      not null	enable,
    "owner_list"	varchar(256)	not null	enable,
    "notify_list"	varchar(256)	null,
    "noworldaccess"	number(1)       null,
    "distgroup"         varchar(8)      null
);

create unique index "metaproj_pk" on "metaproj"("id");

alter table "metaproj" add constraint "metaproj_pk"
primary key ("id") using index "metaproj_pk";

create unique index "metaproj_idx1" on "metaproj"("name");

alter table "metaproj" add constraint "metaproj_idx1"
unique ("name") using index "metaproj_idx1";

create sequence "metaproj_seq";

grant select on "metaproj" to __rouser__;
grant select, insert, update, delete on "metaproj" to __rwuser__;
grant select, alter on "metaproj_seq" to __rwuser__;

-- metaproj_attrs

create table "metaproj_attrs" (
    "id"		number(11)	not null	enable,
    "metaproj"		number(11)	not null	enable,
    "name"		varchar(256)	not null	enable,
    "value"		varchar(512)	not null	enable
);

create unique index "metaproj_attrs_pk" on "metaproj_attrs"("id");

alter table "metaproj_attrs" add constraint "metaproj_attrs_pk"
primary key ("id") using index "metaproj_attrs_pk";

create unique index "metaproj_attrs_idx1" on "metaproj_attrs"("metaproj","name");

alter table "metaproj_attrs" add constraint "metaproj_attrs_idx1"
unique ("metaproj","name") using index "metaproj_attrs_idx1";

alter table "metaproj_attrs" add constraint "metaproj_attrs_fk1"
foreign key ("metaproj") references "metaproj"("id");

create sequence "metaproj_attrs_seq";

grant select on "metaproj_attrs" to __rouser__;
grant select, insert, update, delete on "metaproj_attrs" to __rwuser__;
grant select, alter on "metaproj_attrs_seq" to __rwuser__;

-- project

create table "project" (
    "id"		number(11)	not null	enable,
    "metaproj"    	number(11) 	not null	enable,
    "name"        	varchar(64) 	not null	enable,
    "cell"        	number(11)    	not null	enable,
    "movelock"		varchar(1024)	null,
    "owner_list"	varchar(256)	null,
    "notify_list"	varchar(256)	null,
    "noworldaccess"	number(1)       null,
    "distgroup"         varchar(8)      null
);

create unique index "project_pk" on "project"("id");

alter table "project" add constraint "project_pk"
primary key ("id") using index "project_pk";

create unique index "project_idx1" on "project"("metaproj","name");

alter table "project" add constraint "project_idx1"
unique ("metaproj","name") using index "project_idx1";

alter table "project" add constraint "project_fk1"
foreign key ("metaproj") references "metaproj"("id");

alter table "project" add constraint "project_fk2"
foreign key ("cell") references "cell"("id");

create sequence "project_seq";

grant select on "project" to __rouser__;
grant select, insert, update, delete on "project" to __rwuser__;
grant select, alter on "project_seq" to __rwuser__;

-- project_attrs

create table "project_attrs" (
    "id"		number(11)	not null	enable,
    "project"           number(11)      not null	enable,
    "name"              varchar(256)    not null	enable,
    "value"             varchar(512)    not null	enable
);

create unique index "project_attrs_pk" on "project_attrs"("id");

alter table "project_attrs" add constraint "project_attrs_pk"
primary key ("id") using index "project_attrs_pk";

create unique index "project_attrs_idx1" on "project_attrs"("project","name");

alter table "project_attrs" add constraint "project_attrs_idx1"
unique ("project","name") using index "project_attrs_idx1";

alter table "project_attrs" add constraint "project_attrs_fk1"
foreign key ("project") references "project"("id");

create sequence "project_attrs_seq";

grant select on "project_attrs" to __rouser__;
grant select, insert, update, delete on "project_attrs" to __rwuser__;
grant select, alter on "project_attrs_seq" to __rwuser__;

-- release

create table "release" (
    "id"		number(11)	not null	enable,
    "project"     	number(11) 	not null	enable,
    "name"        	varchar(128) 	not null	enable,
    "stage"       	varchar(64) 	default 'dev' not null	enable,
    "locked"      	number(1),
    "destroyed"   	date,
    "packaged"   	date,
    "uploaded"   	date,
    "downloaded"   	date,
    "noworldaccess"	number(1)       null,
    "distgroup"         varchar(8)      null,
    "cloneof"           number(11)      null
);

create unique index "release_pk" on "release"("id");

alter table "release" add constraint "release_pk"
primary key ("id") using index "release_pk";

create unique index "release_idx1" on "release"("project","name");

alter table "release" add constraint "release_idx1"
unique ("project","name") using index "release_idx1";

alter table "release" add constraint "release_fk1"
foreign key ("project") references "project"("id");

alter table "release" add constraint "release_fk2"
foreign key ("cloneof") references "release"("id");

create sequence "release_seq";

grant select on "release" to __rouser__;
grant select, insert, update, delete on "release" to __rwuser__;
grant select, alter on "release_seq" to __rwuser__;

-- release_attrs

create table "release_attrs" (
    "id"		number(11)	not null	enable,
    "release"           number(11)      not null	enable,
    "name"              varchar(256)    not null	enable,
    "value"             varchar(512)    not null	enable
);

create unique index "release_attrs_pk" on "release_attrs"("id");

alter table "release_attrs" add constraint "release_attrs_pk"
primary key ("id") using index "release_attrs_pk";

create unique index "release_attrs_idx1" on "release_attrs"("release","name");

alter table "release_attrs" add constraint "release_attrs_idx1"
unique ("release","name") using index "release_attrs_idx1";

alter table "release_attrs" add constraint "release_attrs_fk1"
foreign key ("release") references "release"("id");

create sequence "release_attrs_seq";

grant select on "release_attrs" to __rouser__;
grant select, insert, update, delete on "release_attrs" to __rwuser__;
grant select, alter on "release_attrs_seq" to __rwuser__;

-- releasealias

create table "releasealias" (
    "id"		number(11)	not null	enable,
    "project"           number(11)      not null	enable,
    "name"              varchar(128)    not null	enable,
    "target"            varchar(128)    not null	enable
);

create unique index "releasealias_pk" on "releasealias"("id");

alter table "releasealias" add constraint "releasealias_pk"
primary key ("id") using index "releasealias_pk";

create unique index "releasealias_idx1" on "releasealias"("project","name");

alter table "releasealias" add constraint "releasealias_idx1"
unique ("project","name") using index "releasealias_idx1";

alter table "releasealias" add constraint "releasealias_fk1"
foreign key ("project") references "project"("id");

create sequence "releasealias_seq";

grant select on "releasealias" to __rouser__;
grant select, insert, update, delete on "releasealias" to __rwuser__;
grant select, alter on "releasealias_seq" to __rwuser__;

-- releasealias_attrs

create table "releasealias_attrs" (
    "id"		number(11)	not null	enable,
    "releasealias"      number(11)      not null	enable,
    "name"              varchar(256)    not null	enable,
    "value"             varchar(512)    not null	enable
);

create unique index "releasealias_attrs_pk" on "releasealias_attrs"("id");

alter table "releasealias_attrs" add constraint "releasealias_attrs_pk"
primary key ("id") using index "releasealias_attrs_pk";

create unique index "releasealias_attrs_idx1" on "releasealias_attrs"("releasealias","name");

alter table "releasealias_attrs" add constraint "releasealias_attrs_idx1"
unique ("releasealias","name") using index "releasealias_attrs_idx1";

alter table "releasealias_attrs" add constraint "releasealias_attrs_fk1"
foreign key ("releasealias") references "releasealias"("id");

create sequence "releasealias_attrs_seq";

grant select on "releasealias_attrs" to __rouser__;
grant select, insert, update, delete on "releasealias_attrs" to __rwuser__;
grant select, alter on "releasealias_attrs_seq" to __rwuser__;

-- releasealias_cellstate

create table "releasealias_cellstate" (
    "id"		number(11)	not null   enable,
    "releasealias"	number(11)	not null   enable,
    "cell"		number(11)	not null   enable,
    "target"		varchar(128)	not null   enable
);

create unique index "releasealias_cellstate_pk"
    on "releasealias_cellstate"("id");

alter table "releasealias_cellstate" add constraint "releasealias_cellstate_pk"
primary key ("id") using index "releasealias_cellstate_pk";

create unique index "releasealias_cellstate_idx1"
    on "releasealias_cellstate"("releasealias","cell");

alter table "releasealias_cellstate" add constraint "releasealias_cellstate_idx1"
unique ("releasealias","cell") using index "releasealias_cellstate_idx1";

alter table "releasealias_cellstate" add constraint "releasealias_cellstate_fk1"
foreign key ("releasealias") references "releasealias"("id");

alter table "releasealias_cellstate" add constraint "releasealias_cellstate_fk2"
foreign key ("cell") references "cell"("id");

create sequence "releasealias_cellstate_seq";

grant select on "releasealias_cellstate" to __rouser__;
grant select, insert, update, delete on "releasealias_cellstate" to __rwuser__;
grant select, alter on "releasealias_cellstate_seq" to __rwuser__;

-- dependency_release

create table "dependency_release"
(
    "id"                 number(11) 	not null	enable,
    "dependent_release"  number(11) 	not null	enable,
    "release"            number(11) 	not null	enable,
    "type"               varchar(128) 	default 'runtime' not null	enable
);

create unique index "dependency_release_pk" on "dependency_release"("id");

alter table "dependency_release" add constraint "dependency_release_pk"
primary key ("id") using index "dependency_release_pk";

create unique index "dependency_release_idx1"
on "dependency_release"("dependent_release","release","type");

alter table "dependency_release" add constraint "dependency_release_idx1"
unique ("dependent_release","release","type") using index "dependency_release_idx1";

alter table "dependency_release" add constraint "dependency_release_fk1"
foreign key ("dependent_release") references "release"("id");

alter table "dependency_release" add constraint "dependency_release_fk2"
foreign key ("release") references "release"("id");

create sequence "dependency_release_seq";

grant select on "dependency_release" to __rouser__;
grant select, insert, update, delete on "dependency_release" to __rwuser__;
grant select, alter on "dependency_release_seq" to __rwuser__;

-- dependency_releasealias

create table "dependency_releasealias"
(
    "id"                 number(11) 	not null	enable,
    "dependent_release"  number(11) 	not null	enable,
    "releasealias"       number(11) 	not null	enable,
    "type"               varchar(128) 	default 'runtime' not null	enable
);

create unique index "dependency_releasealias_pk" on "dependency_releasealias"("id");

alter table "dependency_releasealias" add constraint "dependency_releasealias_pk"
primary key ("id") using index "dependency_releasealias_pk";

create unique index "dependency_releasealias_idx1" on
"dependency_releasealias"("dependent_release","releasealias","type");

alter table "dependency_releasealias" add constraint "dependency_releasealias_idx1"
unique ("dependent_release","releasealias","type")
using index "dependency_releasealias_idx1";

alter table "dependency_releasealias" add constraint "dependency_releasealias_fk1"
foreign key ("dependent_release") references "release"("id");

alter table "dependency_releasealias" add constraint "dependency_releasealias_fk2"
foreign key ("releasealias") references "releasealias"("id");

create sequence "dependency_releasealias_seq";

grant select on "dependency_releasealias" to __rouser__;
grant select, insert, update, delete on "dependency_releasealias" to __rwuser__;
grant select, alter on "dependency_releasealias_seq" to __rwuser__;

-- install

create table "install" (
    "id"		number(11)	not null	enable,
    "release"		number(11) 	not null	enable,
    "name"       	varchar(128) 	not null	enable,
    "spaceused"  	number(22) 	default 0 not null	enable,
    "filecount"  	number(22) 	default 0 not null	enable,
    "dircount"   	number(22) 	default 0 not null	enable,
    "linkcount"  	number(22) 	default 0 not null	enable,
    "checksum"   	varchar(128)	null,
    "checktime"		number(22)	default 0 not null	enable,
    "cloneof"           number(11)      null
);

create unique index "install_pk" on "install"("id");

alter table "install" add constraint "install_pk"
primary key ("id") using index "install_pk";

create unique index "install_idx1" on "install"("release","name");

alter table "install" add constraint "install_idx1"
unique ("release","name") using index "install_idx1";

alter table "install" add constraint "install_fk1"
foreign key ("release") references "release"("id");

alter table "install" add constraint "install_fk2"
foreign key ("cloneof") references "install"("id");

create sequence "install_seq";

grant select on "install" to __rouser__;
grant select, insert, update, delete on "install" to __rwuser__;
grant select, alter on "install_seq" to __rwuser__;

-- install_attrs

create table "install_attrs" (
    "id"		number(11)	not null	enable,
    "install"           number(11)    	not null	enable,
    "name"              varchar(256)    not null	enable,
    "value"             varchar(512)    not null	enable
);

create unique index "install_attrs_pk" on "install_attrs"("id");

alter table "install_attrs" add constraint "install_attrs_pk"
primary key ("id") using index "install_attrs_pk";

create unique index "install_attrs_idx1" on "install_attrs"("install","name");

alter table "install_attrs" add constraint "install_attrs_idx1"
unique ("install","name") using index "install_attrs_idx1";

alter table "install_attrs" add constraint "install_attrs_fk1"
foreign key ("install") references "install"("id");

create sequence "install_attrs_seq";

grant select on "install_attrs" to __rouser__;
grant select, insert, update, delete on "install_attrs" to __rwuser__;
grant select, alter on "install_attrs_seq" to __rwuser__;

-- install_cellstate

create table "install_cellstate" (
    "id"		number(11)	not null                enable,
    "install"           number(11)    	not null                enable,
    "cell"              number(11)    	not null                enable,
    "updatetime"	number(22)	not null        	enable
);

create unique index "install_cellstate_pk" on "install_cellstate"("id");

alter table "install_cellstate" add constraint "install_cellstate_pk"
primary key ("id") using index "install_cellstate_pk";

create unique index "install_cellstate_idx1" on "install_cellstate"("install","cell");

alter table "install_cellstate" add constraint "install_cellstate_idx1"
unique ("install","cell") using index "install_cellstate_idx1";

alter table "install_cellstate" add constraint "install_cellstate_fk1"
foreign key ("install") references "install"("id");

alter table "install_cellstate" add constraint "install_cellstate_fk2"
foreign key ("cell") references "cell"("id");

create sequence "install_cellstate_seq";

grant select on "install_cellstate" to __rouser__;
grant select, insert, update, delete on "install_cellstate" to __rwuser__;
grant select, alter on "install_cellstate_seq" to __rwuser__;

-- install_auditstate

create table "install_auditstate" (
    "id"		number(11)	not null	enable,
    "install"           number(11)    	not null	enable,
    "name"              varchar(256)    not null	enable,
    "audittime"	        number(22)	default 0 not null	enable,
    "status"		number(1)	default 0 not null      enable
);

create unique index "install_auditstate_pk" on "install_auditstate"("id");

alter table "install_auditstate" add constraint "install_auditstate_pk"
primary key ("id") using index "install_auditstate_pk";

create unique index "install_auditstate_idx1" on "install_auditstate"("install","name");

alter table "install_auditstate" add constraint "install_auditstate_idx1"
unique ("install","name") using index "install_auditstate_idx1";

alter table "install_auditstate" add constraint "install_auditstate_fk1"
foreign key ("install") references "install"("id");

create sequence "install_auditstate_seq";

grant select on "install_auditstate" to __rouser__;
grant select, insert, update, delete on "install_auditstate" to __rwuser__;
grant select, alter on "install_auditstate_seq" to __rwuser__;

-- grouprights

create table "grouprights" (
    "id"                number(11)      not null	enable,
    "metaproj"          number(11)      not null	enable,
    "role"              varchar(64)     not null	enable,
    "groupname"		varchar(8)	not null	enable
);

create unique index "grouprights_pk" on "grouprights"("id");

alter table "grouprights" add constraint "grouprights_pk"
primary key ("id") using index "grouprights_pk";

create unique index "grouprights_idx1"
on "grouprights"("metaproj","role","groupname");

alter table "grouprights" add constraint "grouprights_idx1"
unique ("metaproj","role","groupname") using index "grouprights_idx1";

alter table "grouprights" add constraint "grouprights_fk1"
foreign key ("metaproj") references "metaproj"("id");

create sequence "grouprights_seq";

grant select on "grouprights" to __rouser__;
grant select, insert, update, delete on "grouprights" to __rwuser__;
grant select, alter on "grouprights_seq" to __rwuser__;

-- userrights

create table "userrights" (
    "id"                number(11)      not null	enable,
    "metaproj"          number(11)      not null	enable,
    "role"              varchar(64)     not null	enable,
    "username"		varchar(8)	not null	enable
);

create unique index "userrights_pk" on "userrights"("id");

alter table "userrights" add constraint "userrights_pk"
primary key ("id") using index "userrights_pk";

create unique index "userrights_idx1"
on "userrights"("metaproj","role","username");

alter table "userrights" add constraint "userrights_idx1"
unique ("metaproj","role","username") using index "userrights_idx1";

alter table "userrights" add constraint "userrights_fk1"
foreign key ("metaproj") references "metaproj"("id");

create sequence "userrights_seq";

grant select on "userrights" to __rouser__;
grant select, insert, update, delete on "userrights" to __rwuser__;
grant select, alter on "userrights_seq" to __rwuser__;

-- platform

create table "platform" (
    "id"		number(11)	not null	enable,
    "name"              varchar(64)     not null	enable,
    "backwards"         number(11)      null,
    "emulates"          number(11)      null
);

create unique index "platform_pk" on "platform"("id");

alter table "platform" add constraint "platform_pk"
primary key ("id") using index "platform_pk";

create unique index "platform_idx1" on "platform"("name");

alter table "platform" add constraint "platform_idx1"
unique ("name") using index "platform_idx1";

alter table "platform" add constraint "platform_fk1"
foreign key ("backwards") references "platform"("id");

alter table "platform" add constraint "platform_fk2"
foreign key ("emulates") references "platform"("id");

create sequence "platform_seq";

grant select on "platform" to __rouser__;
grant select, insert, update, delete on "platform" to __rwuser__;
grant select, alter on "platform_seq" to __rwuser__;

-- platform_alias

create table "platform_alias" (
    "id"		number(11)	not null	enable,
    "name"              varchar(64)     not null	enable,
    "platform"          number(11)      null
);

create unique index "platform_alias_pk" on "platform_alias"("id");

alter table "platform_alias" add constraint "platform_alias_pk"
primary key ("id") using index "platform_alias_pk";

create unique index "platform_alias_idx1" on "platform_alias"("name");

alter table "platform_alias" add constraint "platform_alias_idx1"
unique ("name") using index "platform_alias_idx1";

alter table "platform_alias" add constraint "platform_alias_fk1"
foreign key ("platform") references "platform"("id");

create sequence "platform_alias_seq";

grant select on "platform_alias" to __rouser__;
grant select, insert, update, delete on "platform_alias" to __rwuser__;
grant select, alter on "platform_alias_seq" to __rwuser__;

-- platform_instance

create table "platform_instance" (
    "id"		number(11)	not null	enable,
    "name"              varchar(64)     not null	enable,
    "platform"          number(11)      not null	enable,
    "backwards"         number(11)      null,
    "emulates"          number(11)      null
);

create unique index "platform_instance_pk" on "platform_instance"("id");

alter table "platform_instance" add constraint "platform_instance_pk"
primary key ("id") using index "platform_instance_pk";

create unique index "platform_instance_idx1" on "platform_instance"("name");

alter table "platform_instance" add constraint "platform_instance_idx1"
unique ("name") using index "platform_instance_idx1";

alter table "platform_instance" add constraint "platform_instance_fk1"
foreign key ("platform") references "platform"("id");

alter table "platform_instance" add constraint "platform_instance_fk2"
foreign key ("backwards") references "platform_instance"("id");

alter table "platform_instance" add constraint "platform_instance_fk3"
foreign key ("emulates") references "platform_instance"("id");

create sequence "platform_instance_seq";

grant select on "platform_instance" to __rouser__;
grant select, insert, update, delete on "platform_instance" to __rwuser__;
grant select, alter on "platform_instance_seq" to __rwuser__;

-- platform_alias

create table "platform_instance_alias" (
    "id"		number(11)	not null	enable,
    "name"              varchar(64)     not null	enable,
    "platforminstance"  number(11)      null
);

create unique index "platform_instance_alias_pk"
on "platform_instance_alias"("id");

alter table "platform_instance_alias"
add constraint "platform_instance_alias_pk"
primary key ("id") using index "platform_instance_alias_pk";

create unique index "platform_instance_alias_idx1"
on "platform_instance_alias"("name");

alter table "platform_instance_alias"
add constraint "platform_instance_alias_idx1"
unique ("name") using index "platform_instance_alias_idx1";

alter table "platform_instance_alias"
add constraint "platform_instance_alias_fk1"
foreign key ("platforminstance") references "platform_instance"("id");

create sequence "platform_instance_alias_seq";

grant select on "platform_instance_alias" to __rouser__;
grant select, insert, update, delete on "platform_instance_alias" to __rwuser__;
grant select, alter on "platform_instance_alias_seq" to __rwuser__;

-- history

-- NOTE: There are NO foriegn keys here, 'cause we want the history
-- table to have old stale data, by design.

create table "history"
(
  "id"             number(11) 		not null,

  "parent"         number(11) 		null,

  "command"        varchar(32) 		not null,
  "request"        varchar(4000) 	not null,
  "starttime"      timestamp 		null,
  "logfile"        varchar(1024) 	null,
  "authuser"       varchar(32) 		not null,
  "efshost"        varchar(128) 	not null,
  "efsversion"     varchar(8) 		not null,
  "endtime"        timestamp,
  "status"         integer,
  "pid"            number(6) 		default 0 not null,

  "release"        varchar(128),
  "region"         varchar(24),
  "campus"         varchar(64),
  "location"       varchar(128),
  "cell"           varchar(256),
  "metaproj"       varchar(32),
  "project"        varchar(64),
  "install"        varchar(128),
  "releasealias"   varchar(128),
  "target"         varchar(128),
  "hosttype"       varchar(8),
  "stage"	   varchar(64),
  "username"       varchar(8),
  "groupname"      varchar(8),
  "userid"         number(12),
  "groupid"        number(12),
  "platform"       varchar(64),
  "platforminstance" varchar(64),
  "platformalias"  varchar(64),
  "platforminstancealias" varchar(64),
  "platformbuild"  varchar(64),
  "backwards"      varchar(64),
  "emulates"       varchar(64),
  "fileserver"     varchar(128),
  "fileshare"      varchar(128),
  "fileqtree"      varchar(128),
  "filetype"       varchar(4),
  "efsserver"      varchar(256),
  "domain"         varchar(512) 	default 'x.y.z' not null,
  "business"	   varchar(24),
  "division"	   varchar(64),
  "pod"		   varchar(256),
  "hostclass"	   varchar(128),
  "cabinet"	   varchar(256),

  "feature"        varchar(64),
  "parameter"      varchar(64),
  "ffrule"         varchar(64),

  "home"           varchar(8)

);

-- XXX: The 1000000 can be dropped once the ML database is converted.
-- create sequence history_seq;
create sequence "history_seq" start with 1000000;

grant select on "history" to __rouser__;
grant select, insert, update, delete on "history" to __rwuser__;
grant select, alter on "history_seq" to __rwuser__;

-- diststats

-- NOTE: There are NO foriegn keys here, 'cause we want the history
-- able to have old stale data, by design.... and this data is linked
-- to the history table...

create table "diststats" (
    "id"                  number(11)      not null,
    "history"             number(11)      not null,
    "starttime"           timestamp       null,
    "endtime"             timestamp       null,
    "status"              number(11)             null,
    "src_cell"            varchar(256)    not null,
    "dest_cell"           varchar(256)    not null,
    "metaproj"            varchar(32)     not null,
    "project"             varchar(64)     not null,
    "release"             varchar(128)    not null,
    "bytes_sent"          number(11)             null,
    "bytes_received"      number(11)             null,
    "bytes_rate"          varchar(24)     null,
    "total_size"          number(11)             null,
    "speedup"             number(11)             null,
    "file_count"          number(11)             null,
    "file_xfer_count"     number(11)             null,
    "file_size"           number(11)             null,
    "file_xfer_size"      number(11)             null
);


-- XXX: The 1000000 can be dropped once the ML database is converted.
-- create sequence diststats_seq;
create sequence "diststats_seq" start with 1000000;

grant select on "diststats" to __rouser__;
grant select, insert, update, delete on "diststats" to __rwuser__;
grant select, alter on "diststats_seq" to __rwuser__;

-- rsyncstats

create table "rsyncstats" (
    "id"                  number(11)      not null,
    "diststats"           number(11)             not null,
    "starttime"           timestamp       null,
    "endtime"             timestamp       null,
    "status"              number(11)             null,
    "src_cell"            varchar(256)    not null,
    "dest_cell"           varchar(256)    not null,
    "metaproj"            varchar(32)     not null,
    "project"             varchar(64)     not null,
    "release"             varchar(128)    not null,
    "install"             varchar(128)    not null,
    "bytes_sent"          number(11)             null,
    "bytes_received"      number(11)             null,
    "bytes_rate"          varchar(24)     null,
    "total_size"          number(11)             null,
    "speedup"             number(11)             null,
    "file_count"          number(11)             null,
    "file_xfer_count"     number(11)             null,
    "file_size"           number(11)             null,
    "file_xfer_size"      number(11)             null
);

-- XXX: The 1000000 can be dropped once the ML database is converted.
-- create sequence rsyncstats_seq;
create sequence "rsyncstats_seq" start with 1000000;

grant select on "rsyncstats" to __rouser__;
grant select, insert, update, delete on "rsyncstats" to __rwuser__;
grant select, alter on "rsyncstats_seq" to __rwuser__;

-- business

create table "business" (
    "id"                number(11)      not null,
    "name"		varchar(24)	not null,
    "description"       varchar(1024)   not null
);

create unique index "business_pk" on "business"("id");

alter table "business" add constraint "business_pk"
primary key ("id") using index "business_pk";

create unique index "business_idx1" on "business"("name");

alter table "business" add constraint "business_idx1"
unique ("name") using index "business_idx1";

create sequence "business_seq";

grant select on "business" to __rouser__;
grant select, insert, update, delete on "business" to __rwuser__;
grant select, alter on "business_seq" to __rwuser__;

-- business_attrs

create table "business_attrs" (
    "id"		number(11)	not null	enable,
    "business"          number(11)      not null	enable,
    "name"              varchar(256)    not null	enable,
    "value"             varchar(512)    not null	enable
);

create unique index "business_attrs_pk" on "business_attrs"("id");

alter table "business_attrs" add constraint "business_attrs_pk"
primary key ("id") using index "business_attrs_pk";

create unique index "business_attrs_idx1" on "business_attrs"("business","name");

alter table "business_attrs" add constraint "business_attrs_idx1"
unique ("business","name") using index "business_attrs_idx1";

alter table "business_attrs" add constraint "business_attrs_fk1"
foreign key ("business") references "business"("id");

create sequence "business_attrs_seq";

grant select on "business_attrs" to __rouser__;
grant select, insert, update, delete on "business_attrs" to __rwuser__;
grant select, alter on "business_attrs_seq" to __rwuser__;

-- division

create table "division" (
    "id"		number(11)	not null	enable,
    "business"		number(11)	not null	enable,
    "name"		varchar(64)	not null	enable,
    "description"       varchar(1024)   not null        enable
);

create unique index "division_pk" on "division"("id");

alter table "division" add constraint "division_pk"
primary key ("id") using index "division_pk";

create unique index "division_idx1" on "division"("name");

alter table "division" add constraint "division_idx1"
unique ("name") using index "division_idx1";

alter table "division" add constraint "division_fk1"
foreign key ("business") references "business"("id");

create sequence "division_seq";

grant select on "division" to __rouser__;
grant select, insert, update, delete on "division" to __rwuser__;
grant select, alter on "division_seq" to __rwuser__;

-- division_attrs

create table "division_attrs" (
    "id"		number(11)	not null	enable,
    "division"          number(11)      not null	enable,
    "name"              varchar(256)    not null	enable,
    "value"             varchar(512)    not null	enable
);

create unique index "division_attrs_pk" on "division_attrs"("id");

alter table "division_attrs" add constraint "division_attrs_pk"
primary key ("id") using index "division_attrs_pk";

create unique index "division_attrs_idx1" on "division_attrs"("division","name");

alter table "division_attrs" add constraint "division_attrs_idx1"
unique ("division","name") using index "division_attrs_idx1";

alter table "division_attrs" add constraint "division_attrs_fk1"
foreign key ("division") references "division"("id");

create sequence "division_attrs_seq";

grant select on "division_attrs" to __rouser__;
grant select, insert, delete, update on "division_attrs" to __rwuser__;
grant select, alter on "division_attrs_seq" to __rwuser__;

-- pod

create table "pod" (
    "id"		number(11)	not null	enable,
    "location"		number(11)	not null	enable,
    "name"		varchar(256)    not null	enable,
    "description"       varchar(1024)   not null        enable
);

create unique index "pod_pk" on "pod"("id");

alter table "pod" add constraint "pod_pk"
primary key ("id") using index "pod_pk";

create unique index "pod_idx1" on "pod"("location","name");

alter table "pod" add constraint "pod_idx1"
unique ("location","name") using index "pod_idx1";

alter table "pod" add constraint "pod_fk1"
foreign key ("location") references "location"("id");

create sequence "pod_seq";

grant select on "pod" to __rouser__;
grant select, insert, update, delete on "pod" to __rwuser__;
grant select, alter on "pod_seq" to __rwuser__;

-- pod_attrs

create table "pod_attrs" (
    "id"		number(11)	not null	enable,
    "pod"	        number(11)      not null	enable,
    "name"              varchar(256)    not null	enable,
    "value"             varchar(512)    not null	enable
);

create unique index "pod_attrs_pk" on "pod_attrs"("id");

alter table "pod_attrs" add constraint "pod_attrs_pk"
primary key ("id") using index "pod_attrs_pk";

create unique index "pod_attrs_idx1" on "pod_attrs"("pod","name");

alter table "pod_attrs" add constraint "pod_attrs_idx1"
unique ("pod","name") using index "pod_attrs_idx1";

alter table "pod_attrs" add constraint "pod_attrs_fk1"
foreign key ("pod") references "pod"("id");

create sequence "pod_attrs_seq";

grant select on "pod_attrs" to __rouser__;
grant select, insert, delete, update on "pod_attrs" to __rwuser__;
grant select, alter on "pod_attrs_seq" to __rwuser__;

-- hostclass

create table "hostclass" (
    "id"                number(11)      not null        enable,
    "name"		varchar(128)	not null        enable,
    "description"       varchar(1024)   not null        enable
);

create unique index "hostclass_pk" on "hostclass"("id");

alter table "hostclass" add constraint "hostclass_pk"
primary key ("id") using index "hostclass_pk";

create unique index "hostclass_idx1" on "hostclass"("name");

alter table "hostclass" add constraint "hostclass_idx1"
unique ("name") using index "hostclass_idx1";

create sequence "hostclass_seq";

grant select on "hostclass" to __rouser__;
grant select, insert, update, delete on "hostclass" to __rwuser__;
grant select, alter on "hostclass_seq" to __rwuser__;

-- hostclass_attrs

create table "hostclass_attrs" (
    "id"		number(11)	not null	enable,
    "hostclass"         number(11)      not null	enable,
    "name"              varchar(256)    not null	enable,
    "value"             varchar(512)    not null	enable
);

create unique index "hostclass_attrs_pk" on "hostclass_attrs"("id");

alter table "hostclass_attrs" add constraint "hostclass_attrs_pk"
primary key ("id") using index "hostclass_attrs_pk";

create unique index "hostclass_attrs_idx1" on "hostclass_attrs"("hostclass","name");

alter table "hostclass_attrs" add constraint "hostclass_attrs_idx1"
unique ("hostclass","name") using index "hostclass_attrs_idx1";

alter table "hostclass_attrs" add constraint "hostclass_attrs_fk1"
foreign key ("hostclass") references "hostclass"("id");

create sequence "hostclass_attrs_seq";

grant select on "hostclass_attrs" to __rouser__;
grant select, insert, update, delete on "hostclass_attrs" to __rwuser__;
grant select, alter on "hostclass_attrs_seq" to __rwuser__;

-- cabinet

create table "cabinet" (
    "id"		number(11)	not null	enable,
    "location"		number(11)	not null	enable,
    "name"		varchar(256)	not null	enable
);

create unique index "cabinet_pk" on "cabinet"("id");

alter table "cabinet" add constraint "cabinet_pk"
primary key ("id") using index "cabinet_pk";

create unique index "cabinet_idx1" on "cabinet"("name");

alter table "cabinet" add constraint "cabinet_idx1"
unique ("name") using index "cabinet_idx1";

alter table "cabinet" add constraint "cabinet_fk1"
foreign key ("location") references "location"("id");

create sequence "cabinet_seq";

grant select on "cabinet" to __rouser__;
grant select, insert, update, delete on "cabinet" to __rwuser__;
grant select, alter on "cabinet_seq" to __rwuser__;

-- cabinet_attrs

create table "cabinet_attrs" (
    "id"		number(11)	not null	enable,
    "cabinet"           number(11)      not null	enable,
    "name"              varchar(256)    not null	enable,
    "value"             varchar(512)    not null	enable
);

create unique index "cabinet_attrs_pk" on "cabinet_attrs"("id");

alter table "cabinet_attrs" add constraint "cabinet_attrs_pk"
primary key ("id") using index "cabinet_attrs_pk";

create unique index "cabinet_attrs_idx1" on "cabinet_attrs"("cabinet","name");

alter table "cabinet_attrs" add constraint "cabinet_attrs_idx1"
unique ("cabinet","name") using index "cabinet_attrs_idx1";

alter table "cabinet_attrs" add constraint "cabinet_attrs_fk1"
foreign key ("cabinet") references "cabinet"("id");

create sequence "cabinet_attrs_seq";

grant select on "cabinet_attrs" to __rouser__;
grant select, insert, delete, update on "cabinet_attrs" to __rwuser__;
grant select, alter on "cabinet_attrs_seq" to __rwuser__;

-- platform_build

create table "platform_build" (
    "id"		number(11)	not null	enable,
    "name"        	varchar(64) 	not null	enable,
    "platform"    	number(11) 	not null	enable,
    "kernel"		varchar(1024)	not null        enable,
    "initrd"		varchar(1024)	not null        enable,
    "options"		varchar(1024)	not null        enable
);

create unique index "platform_build_pk" on "platform_build"("id");

alter table "platform_build" add constraint "platform_build_pk"
primary key ("id") using index "platform_build_pk";

create unique index "platform_build_idx1" on "platform_build"("name");

alter table "platform_build" add constraint "platform_build_idx1"
unique ("name") using index "platform_build_idx1";

alter table "platform_build" add constraint "platform_build_fk1"
foreign key ("platform") references "platform"("id");

create sequence "platform_build_seq";

grant select on "platform_build" to __rouser__;
grant select, insert, update, delete on "platform_build" to __rwuser__;
grant select, alter on "platform_build_seq" to __rwuser__;

-- platform_build_attrs

create table "platform_build_attrs" (
    "id"		number(11)	not null	enable,
    "platformbuild"     number(11)      not null	enable,
    "name"              varchar(256)    not null	enable,
    "value"             varchar(512)    not null	enable
);

create unique index "platform_build_attrs_pk" on "platform_build_attrs"("id");

alter table "platform_build_attrs" add constraint "platform_build_attrs_pk"
primary key ("id") using index "platform_build_attrs_pk";

create unique index "platform_build_attrs_idx1" on "platform_build_attrs"("platformbuild","name");

alter table "platform_build_attrs" add constraint "platform_build_attrs_idx1"
unique ("platformbuild","name") using index "platform_build_attrs_idx1";

alter table "platform_build_attrs" add constraint "platform_build_attrs_fk1"
foreign key ("platformbuild") references "platform_build"("id");

create sequence "platform_build_attrs_seq";

grant select on "platform_build_attrs" to __rouser__;
grant select, insert, update, delete on "platform_build_attrs" to __rwuser__;
grant select, alter on "platform_build_attrs_seq" to __rwuser__;

-- feature

create table "feature" (
    "id"		number(11)	not null	enable,
    "name"              varchar(64)     not null	enable,
    "value"             varchar(1024)   not null        enable
);

create unique index "feature_pk" on "feature"("id");

alter table "feature" add constraint "feature_pk"
primary key ("id") using index "feature_pk";

create unique index "feature_idx1" on "feature"("name");

alter table "feature" add constraint "feature_idx1"
unique ("name") using index "feature_idx1";

create sequence "feature_seq";

grant select on "feature" to __rouser__;
grant select, insert, update, delete on "feature" to __rwuser__;
grant select, alter on "feature_seq" to __rwuser__;

-- ffrule

create table "ffrule" (
    "id"		number(11)	not null	enable,
    "name"              varchar(64)     not null	enable,
    "regex"             varchar(256)    not null	enable,
    "description"       varchar(1024)   not null        enable
);

create unique index "ffrule_pk" on "ffrule"("id");

alter table "ffrule" add constraint "ffrule_pk"
primary key ("id") using index "ffrule_pk";

create unique index "ffrule_idx1" on "ffrule"("name");

alter table "ffrule" add constraint "ffrule_idx1"
unique ("name") using index "ffrule_idx1";

create sequence "ffrule_seq";

grant select on "ffrule" to __rouser__;
grant select, insert, update, delete on "ffrule" to __rwuser__;
grant select, alter on "ffrule_seq" to __rwuser__;

-- parameter

create table "parameter" (
    "id"		number(11)	not null	enable,
    "name"              varchar(64)     not null	enable,
    "value"             varchar(1024)   not null        enable
);

create unique index "parameter_pk" on "parameter"("id");

alter table "parameter" add constraint "parameter_pk"
primary key ("id") using index "parameter_pk";

create unique index "parameter_idx1" on "parameter"("name");

alter table "parameter" add constraint "parameter_idx1"
unique ("name") using index "parameter_idx1";

create sequence "parameter_seq";

grant select on "parameter" to __rouser__;
grant select, insert, update, delete on "parameter" to __rwuser__;
grant select, alter on "parameter_seq" to __rwuser__;

-- sslserver

create table "sslserver" (
    "id"		number(11)	not null	enable,
    "type"              varchar(128) 	not null	enable,
    "efsserver"         number(11)      not null	enable
);

create unique index "sslserver_pk" on "sslserver"("id");

alter table "sslserver" add constraint "sslserver_pk"
primary key ("id") using index "sslserver_pk";

create unique index "sslserver_idx1"
on "sslserver"("efsserver");

create unique index "sslserver_idx2"
on "sslserver"("type");

alter table "sslserver" add constraint "sslserver_fk1"
foreign key ("efsserver") references "efsserver"("id");

create sequence "sslserver_seq";

grant select on "sslserver" to __rouser__;
grant select, insert, update, delete on "sslserver" to __rwuser__;
grant select, alter on "sslserver_seq" to __rwuser__;

-- home

create table "home" (
    "id"		number(11)	not null	enable,
    "cell"              number(11)    	not null	enable,
    "name"              varchar(128)    not null	enable,
    "destroyed"   	date
);

create unique index "home_pk" on "home"("id");

alter table "home" add constraint "home_pk"
primary key ("id") using index "home_pk";

create unique index "home_idx1" on "home"("name");

alter table "home" add constraint "home_idx1"
unique ("name") using index "home_idx1";

alter table "home" add constraint "home_fk1"
foreign key ("cell") references "cell"("id");

create sequence "home_seq";

grant select on "home" to __rouser__;
grant select, insert, update, delete on "home" to __rwuser__;
grant select, alter on "home_seq" to __rwuser__;

-- home_attrs

create table "home_attrs" (
    "id"		number(11)	not null	enable,
    "home"              number(11)	not null	enable,
    "name"              varchar(256)    not null	enable,
    "value"             varchar(512)    not null	enable
);

create unique index "home_attrs_pk" on "home_attrs"("id");

alter table "home_attrs" add constraint "home_attrs_pk"
primary key ("id") using index "home_attrs_pk";

create unique index "home_attrs_idx1" on "home_attrs"("home","name");

alter table "home_attrs" add constraint "home_attrs_idx1"
unique ("home","name") using index "home_attrs_idx1";

alter table "home_attrs" add constraint "home_attrs_fk1"
foreign key ("home") references "home"("id");

create sequence "home_attrs_seq";

grant select on "home_attrs" to __rouser__;
grant select, insert, update, delete on "home_attrs" to __rwuser__;
grant select, alter on "home_attrs_seq" to __rwuser__;

