#!/usr/bin/env perl

use strict;
use warnings;
use English;

use Test::Exception;
use Test::Deep;
use Test::More tests => 17;

use blib;
use EFS;

setup();

my $start_time = time;

my $ft = EFS::FileTree->new({ pathname => q{/tmp/ftdir1} });

isa_ok( $ft, q{EFS::FileTree} );

my @dirs = sort $ft->get_dirnames();
chomp @dirs;

is( @dirs, 3, q{get_dirnames() should return 3 directory names} );

cmp_deeply(
    \@dirs,
    [qw( /tmp/ftdir1 /tmp/ftdir1/ftdir2 /tmp/ftdir1/ftdir3)],
    q{verify directory names}
);

my @files = sort $ft->get_filenames();
chomp @files;

is( @files, 2, q{get_filenames() should return 2 file names} );

cmp_deeply(
    \@files,
    [   qw(/tmp/ftdir1/ftdir2/ftfile2.txt
            /tmp/ftdir1/ftdir3/ftfile3.txt)
    ],
    q{verify file names}
);

my @links = sort $ft->get_linknames();
chomp @links;

is( @links, 1, q{get_linknames() should return 1 link name} );
is( $links[0], q{/tmp/ftdir1/ftlink1.txt}, q{verify link name} );

my $filecount = $ft->get_filecount();
is( $filecount, 2, q{get_filecount() should return 2} );

my $dircount = $ft->get_dircount();
is( $dircount, 3, q{get_dircount() should return 3} );

my $linkcount = $ft->get_linkcount();
is( $linkcount, 1, q{get_linkcount() should return 1} );

# There's no easy way to predict the spaceused.  On Linux, small
# directories will be no smaller than the blksize, but on FreeBSD,
# they can be (eg. blksize == 4096, but size == 512).
#
# my $spaceused = $ft->get_spaceused();
# is( $spaceused, 12_340, q{get_spaceused() should return 12340} );

cleanup();

sub setup {

    my @commands        = (
        q{mkdir /tmp/ftdir1},
        q{mkdir /tmp/ftdir1/ftdir2},
        q{echo '1234567890' > /tmp/ftdir1/ftdir2/ftfile2.txt},
        q{mkdir /tmp/ftdir1/ftdir3},
        q{echo '1234567890' > /tmp/ftdir1/ftdir3/ftfile3.txt},
        q{ln -s /tmp/ftdir1/ftdir2/ftfile2.txt /tmp/ftdir1/ftlink1.txt},
    );

    foreach my $command ( @commands ) {
        my $errors = qx{ $command 2>&1 };
        if ( $CHILD_ERROR ) {
            ok( 0, qq{$command failed: $errors} );
        } else {
            ok( 1, $command );
        }
    }

    return;

}

sub cleanup {

    my $errors = qx{ rm -v -r /tmp/ftdir1 2>&1 };
    if ( $CHILD_ERROR ) {
        ok( 0, qq{cleanup failed: $errors} );
    } else {
        ok( 1, q{destroy test directories, files and link} );
    }

    return;

}

