#!/usr/bin/env perl

use strict;
use warnings;
use English;

use Test::More qw( no_plan );
use File::Basename qw( basename );
use File::Path qw( rmtree );

use lib q{test/lib};
use EFS::Test::Config;

my $config = EFS::Test::Config->new;

my $sshcmd = $config->get_value( q{Global}, q{sshcmd} );

my $ldc_efsserver = $config->get_value( q{LocalDevCell},  q{efsserver} );
my $rdc_efsserver = $config->get_value( q{RemoteDevCell}, q{efsserver} );

my @files = (
    q{/var/efs/etc/cacert.pem},   q{/var/efs/etc/crl.pem},
    q{/var/efs/etc/openssl.conf}, q{/var/efs/ssl},
);

my @localdirs = (
    q{/var/efs/ca},
    glob( q{/var/efs/ca-*} ),
    glob( q{/var/efs/ssl-*} ),
);

my @remotedirs = qx{ $sshcmd $rdc_efsserver "bash -c 'echo /var/efs/ssl-*'" };
chomp( @remotedirs );

foreach my $file (@files) {

    if ( -f $file || -l $file ) {
        unlink ($file) || die qq{Unable to unlink $file: $ERRNO\n};
        ok( 1, qq{unlink $file} );
    }
    else {
        ok( 1, qq{$file already gone} );
    }

    system( qq{$sshcmd $rdc_efsserver rm -f $file} );
    $CHILD_ERROR and die qq{Unable to unlink $rdc_efsserver:$file\n};
    ok( 1, qq{unlink $rdc_efsserver:$file} );

}

foreach my $localdir (@localdirs) {
    rmtree($localdir);
    ok( 1, qq{rmtree $localdir} );
}

foreach my $remotedir (@remotedirs) {

    if ( $remotedir eq q{/var/efs/ssl-*} ) {
        next;
    }

    system qq{$sshcmd $rdc_efsserver /bin/rm -r $remotedir};
    $CHILD_ERROR and die qq{Unable to rm -r $rdc_efsserver:$remotedir\n};

    ok( 1, qq{rm -r $rdc_efsserver:$remotedir} );

}

exit 0;

