#!/usr/bin/env perl

use strict;
use warnings;
use English;

use lib q{test/lib};
use EFS::Test::Config;

use Test::More;

my $config = EFS::Test::Config->new;

my $ldc_efsserver = $config->get_value( q{LocalDevCell}, q{efsserver} );
my $rdc_efsserver = $config->get_value( q{RemoteDevCell}, q{efsserver} );
my $sshcmd        = $config->get_value( q{Global}, q{sshcmd} );

if ( $config->get_value( q{Database}, q{manual} ) ) {
    plan skip_all => q{Automated database setup disabled};
}

my $connect = $config->get_value( q{Database}, q{connect} );

if ( $connect =~ m{oracle}imsx ) {
    plan skip_all => q{Automated database setup only works for MySQL};
}

# Stop the mysql daemon

my $errors = 0;

my $password = qx{cat /var/efs/db/passwd/root};
if ( $CHILD_ERROR ) {
    warn qq{Unable to get database root password\n};
    $errors++;
}

if ( $password ) {
    chomp $password;
    system(qq{mysqladmin shutdown --user=root --password=$password});
    if ( $CHILD_ERROR ) {
        warn qq{Unable to shutdown mysqld\n};
        $errors++;
    }
}

ok( ! $errors, q{Stopped mysqld} );

my $mycnforig = q{};

foreach my $file ( qw( /etc/my.cnf.orig /etc/mysql/my.cnf.orig ) ) {
    next if not -f $file;
    $mycnforig = $file;
    last;
}

if ( not $mycnforig ) {
    die qq{Unable to find the saved my.cnf.orig file!!\n};
}

( my $mycnf = $mycnforig ) =~ s{\.orig$}{}ms;

if ( -l $mycnf && -f $mycnforig ) {
    rename( $mycnforig, $mycnf ) ||
        die qq{Unable to rename $mycnforig -> $mycnf: $ERRNO\n};
}

ok( 1, qq{Restored $mycnf} );

done_testing();

1;

